@@ -2,6 +2,8 @@ import os, sys, re, time, threading
 from http.server import ThreadingHTTPServer, BaseHTTPRequestHandler
 from html import escape
 
+done = False
+
 def main():
     global code
     global done
@@ -15,8 +17,8 @@ def main():
             self.send_header("Content-Type", "text/html")
             self.end_headers()
             self.wfile.write(outfile[:outfile.rindex('.')].encode('utf-8'))
-            s.stop()
             done = True
+            s.stop()
 
     class Server(threading.Thread):
         def run(self):
@@ -28,7 +30,7 @@ def main():
     def repl(foo):
         return foo[0][:foo.span(1)[0]-foo.span(0)[1]] + escape(code) + foo[0][foo.span(1)[1] - foo.span(0)[0]:]
 
-    print("\n------\nPython's Turn!\n------\n")
+    #print("\n------\nPython's Turn!\n------\n")
     outfile = sys.argv[1]
     root_path = os.getenv('APPDATA')+"/Stormworks/data/vehicles/"
     data = open(root_path+outfile).read()
@@ -36,11 +38,11 @@ def main():
     for file in os.scandir(sys.argv[2]+"release"):
         code = open(file.path).read()
         identifier = file.name[:file.name.rindex('.')]
-        print(f"Searching '{outfile}' for Lua block with identifier '{identifier}'")
+        print(f"Searching '{outfile}' for Lua blocks with identifier '{identifier}'")
         data, c = re.subn(f"script=['\"]--{identifier}[\r\n|\n|\r](.*?)['\"]>", repl, data, flags = re.MULTILINE + re.DOTALL)
         open(root_path+outfile, "w").write(data)
-        print(f"\tReplaced {c} code blocks with identifier '{identifier}'.")
-    print("\n------\nBack to you, nameous!\n------\n")
+        print(f"\tReplaced {c} Lua blocks with identifier '{identifier}'.")
+    #print("\n------\nBack to you, nameous!\n------\n")
 
     s = Server()
     s.start()
